package document.manager;
import java.util.ArrayList;
import java.util.Iterator;

public final class Document {

	private static final String OWNER = "Univ. Ioannina";

	private String docName;
	private Topic docTopic;
	private ArrayList<Section> sections;
	private int totalNumPages = 0;
	
	public Document(){
		docName = "noName"; docTopic = null; 
		sections = new ArrayList<Section>();
	}
	
	public Document(String aName, Topic aTopic){
		docName = aName; this.docTopic = aTopic; 
		sections = new ArrayList<Section>();
	}
	
	public void addSection(Section aSection){
		sections.add(aSection);
		System.out.println("New section added, total # sections: " + sections.size());
	}

	public static String getOwner(){return OWNER;}	
	
	public void showDocumentOverview(){ 
		System.out.println(OWNER + " has ths nice document titled: " + docName + " with the topic: " + docTopic.getTitle() + "\n");
	}

	public double computeStats(double hoursSpentPerPage){
		double totalEffortToRead = 0;
		
		Iterator <Section> si = this.sections.iterator();
		Section s = null;
		while (si.hasNext()){
			s = si.next();
			totalNumPages += s.getNumPages();
		}
		totalEffortToRead = totalNumPages * hoursSpentPerPage;
		return totalEffortToRead;
	}
	
	public void showDocumentDetails(){
		double hrsPerPage = 0.1; double totalEffort = 0;

		for(Section s : this.sections){
			//within the body of this for, work with EACH Section s ONE AT A TIME!!!
			System.out.println(s.getTitle() + "\t" + s.getNumPages());
		}
		totalEffort = computeStats(hrsPerPage);		
		System.out.println("num. pages: " + totalNumPages);
		System.out.println("estimated effort to read (hrs): " + totalEffort);
	}


//	public String getName(){return docName;}
//	public Topic getTopic(){return docTopic;}
//	public int getNumSections(){return sections.size();}

}//end class Document


